@@ -33,6 +33,55 @@ class Settings(BaseSettings):
     def parse_args(self, args: List[str]) -> None:
         settings_ref: Settings = self
 
+        class BooleanOptionalAction(Action):
+            settings = settings_ref
+
+            def __init__(  # type: ignore
+                self,
+                option_strings,
+                dest,
+                default=None,
+                type=None,
+                choices=None,
+                required=False,
+                help=None,
+                metavar=None,
+            ):
+
+                _option_strings = []
+                for option_string in option_strings:
+                    _option_strings.append(option_string)
+
+                    if option_string.startswith("--"):
+                        option_string = "--no-" + option_string[2:]
+                        _option_strings.append(option_string)
+
+                if help is not None and default is not None:
+                    help += f" (default: {default})"
+
+                super().__init__(
+                    option_strings=_option_strings,
+                    dest=dest,
+                    nargs=0,
+                    default=default,
+                    type=type,
+                    choices=choices,
+                    required=required,
+                    help=help,
+                    metavar=metavar,
+                )
+
+            def __call__(self, parser, namespace, values, option_string=None):  # type: ignore
+                if self.settings.Config.env_prefix:
+                    dest = self.dest[len(self.settings.Config.env_prefix) :]
+                else:
+                    dest = self.dest
+                if option_string in self.option_strings:
+                    setattr(namespace, dest, not option_string.startswith("--no-"))
+
+            def format_usage(self):  # type: ignore
+                return " | ".join(self.option_strings)
+
         class SetSettingsAction(Action):
             settings = settings_ref
 
@@ -50,7 +99,9 @@ class Settings(BaseSettings):
             parser.add_argument(
                 f"--{name}",
                 type=field.type_,
-                action=SetSettingsAction,
+                action=BooleanOptionalAction
+                if field.type_ is bool
+                else SetSettingsAction,
                 help=field.field_info.title,
             )
         parser.parse_known_args(args)
