@@ -1,5 +1,5 @@
 import tempfile
-from unittest import TestCase, mock
+from unittest import mock
 
 from pydantic import BaseModel
 import pytest
@@ -33,8 +33,8 @@ def make_output(filename):
     producer.start()
 
 
-class TestWorkerCore(TestCase):
-    def test_mem_producer(self):
+class TestWorkerCore:
+    def test_mem_producer(self, monkeypatch):
         class Output(BaseModel):
             key: int
 
@@ -44,10 +44,16 @@ class TestWorkerCore(TestCase):
                     yield Output(key=i)
 
         settings = ProducerSettings(
-            name="producer", version="0.1.0", description="", out_kind=TapKind.MEM
+            name="producer",
+            version="0.1.0",
+            description="",
+            out_kind=TapKind.MEM,
+            debug=True,
+            monitoring=True,
         )
         producer = MyProducer(settings, output_class=Output)
-        producer.parse_args(args=["--out-topic", "test"])
+        producer.parse_args(args=["--out-topic", "test", "--debug"])
+        monkeypatch.setattr(producer, "monitor", mock.MagicMock())
         producer.start()
         assert len(producer.destination.results) == 3
 
@@ -80,7 +86,7 @@ class TestWorkerCore(TestCase):
         outputs = [Output(language="en"), Input(key=1), Output(language="en")]
 
         class MyProcessor(Processor):
-            def process(self, msg):
+            def process(self, msg, id):
                 return outputs.pop(0)
 
         settings = ProcessorSettings(
@@ -105,7 +111,7 @@ class TestWorkerCore(TestCase):
             language: str
 
         class MyProcessor(Processor):
-            def process(self, msg: Input) -> Output:
+            def process(self, msg: Input, id: str) -> Output:
                 return Output(language="en")
 
         settings = ProcessorSettings(
@@ -122,56 +128,6 @@ class TestWorkerCore(TestCase):
         processor.start()
         assert len(processor.destination.results) == 2
 
-    # def test_processor_invalid_message(self):
-    #     class InvalidMessage(Message):
-    #         def is_valid(self):
-    #             return False
-    #
-    #     msgs = [{}, {}, {}]
-    #     config = ProcessorConfig(messageClass=InvalidMessage)
-    #     pro1 = Processor("tester1", "0.1.0", config=config)
-    #     pro1.parse_args(
-    #         args=["--kind", "MEM", "--out-topic", "test"],
-    #         config={"data": msgs},
-    #     )
-    #     pro1.use_retry_topic("optional-retry-topic")
-    #     pro1.start()
-    #     assert len(pro1.destination.results) == 0
-    #     assert len(pro1.retryDestination.results) == 3
-
-    # def test_processor_retry(self):
-    #     class RetryProcessor(Processor):
-    #         def process(self, msg):
-    #             return "Error"
-    #
-    #     msgs = [{"key": "1"}, {"key": "2"}, {"key": "3"}]
-    #     pro1 = RetryProcessor("tester1", "0.1.0")
-    #     pro1.parse_args(
-    #         args=["--kind", "MEM", "--out-topic", "test"],
-    #         config={"data": msgs},
-    #     )
-    #     pro1.use_retry_topic("optional-retry-topic")
-    #     pro1.start()
-    #     assert len(pro1.destination.results) == 0
-    #     assert len(pro1.retryDestination.results) == 3
-
-    # def test_processor_terminated_messages(self):
-    #     class RetryProcessor(Processor):
-    #         def process(self, msg):
-    #             msg.terminates()
-    #             return None
-    #
-    #     msgs = [{"key": "1"}, {"key": "2"}, {"key": "3"}]
-    #     pro1 = RetryProcessor("tester1", "0.1.0")
-    #     pro1.parse_args(
-    #         args=["--kind", "MEM", "--out-topic", "test"],
-    #         config={"data": msgs},
-    #     )
-    #     pro1.use_retry_topic("optional-retry-topic")
-    #     pro1.start()
-    #     assert len(pro1.destination.results) == 0
-    #     assert len(pro1.retryDestination.results) == 0
-
     def test_processor(self):
         class Input(BaseModel):
             key: str
@@ -181,7 +137,7 @@ class TestWorkerCore(TestCase):
             newkey: str
 
         class MyProcessor(Processor):
-            def process(self, input):
+            def process(self, input, id):
                 return Output(key=input.key, newkey="newval")
 
         msgs = [{"key": "1"}, {"key": "2"}, {"key": "3"}]
@@ -196,34 +152,6 @@ class TestWorkerCore(TestCase):
         m = processor.destination.results[0]
         assert m.get("newkey") == "newval"
 
-    # def test_processor_with_cache(self):
-    #     class MyProcessor(Processor):
-    #         def process(self, msg):
-    #             self.logger.info("%s, %s", msg.dct.get("key", None), msg.get("key"))
-    #             msg.update_content({"key3": msg.get("key1")})
-    #             return None
-    #
-    #     msgs = [{"key": "m1"}, {"key": "m2"}, {"key": "m3"}]
-    #     memory = {
-    #         "m1": {"key1": "val11", "key2": "val21"},
-    #         "m2": {"key1": "val12", "key2": "val22"},
-    #         "m3": {"key1": "val13", "key2": "val23"},
-    #     }
-    #     config = ProcessorConfig(cacheKind="MEM")
-    #     pro1 = MyProcessor("tester1", "0.1.0", config=config)
-    #     pro1.parse_args(
-    #         args="--kind MEM --out-topic test --in-fields key1,key2 --out-fields key3".split(),
-    #         config={
-    #             "data": msgs,
-    #             "mem": memory,
-    #         },
-    #     )
-    #     pro1.start()
-    #     assert len(pro1.destination.results) == 3
-    #     m = memory.get("m1")
-    #     assert m.get("key3") == "val11"
-    #     assert m.get("key1") == "val11"
-
     def test_file(self):
         class Input(BaseModel):
             key: int
@@ -234,7 +162,7 @@ class TestWorkerCore(TestCase):
             language: str
 
         class MyProcessor(Processor):
-            def process(self, msg: Input) -> Output:
+            def process(self, msg: Input, id: str) -> Output:
                 return Output(key=msg.key, language=msg.language)
 
         with tempfile.NamedTemporaryFile() as tmpInFile:
@@ -273,7 +201,7 @@ class TestWorkerCore(TestCase):
             language: str
 
         class MyProcessor(Processor):
-            def process(self, msg: Input) -> Output:
+            def process(self, msg: Input, id: str) -> Output:
                 return Output(key=msg.key, language=msg.language)
 
         with tempfile.NamedTemporaryFile() as tmpInFile:
@@ -305,7 +233,7 @@ class TestWorkerCore(TestCase):
             pass
 
         class MyProcessor(Processor):
-            def process(self, msg: Input) -> Output:
+            def process(self, msg: Input, id: str) -> Output:
                 return Output()
 
         msgs = [{}, {}, {}]
@@ -325,6 +253,25 @@ class TestWorkerCore(TestCase):
         class Output(BaseModel):
             pass
 
+        class MyProcessor(Processor):
+            def process(self, msg: Input, id: str) -> Output:
+                raise NotImplementedError
+
+        msgs = [{}, {}, {}]
+        settings = ProcessorSettings(name="processor", version="0.0.0", description="")
+        processor = MyProcessor(settings, input_class=Input, output_class=Output)
+        processor.parse_args(args="--in-kind MEM --out-kind MEM".split())
+        processor.source.data = msgs
+        processor.start()
+        assert len(processor.destination.results) == 0
+
+    def test_mem_processor_raise(self):
+        class Input(BaseModel):
+            pass
+
+        class Output(BaseModel):
+            pass
+
         settings = ProcessorSettings(name="processor", version="0.0.0", description="")
         processor = Processor(settings, input_class=Input, output_class=Output)
         processor.parse_args(args=["--in-kind", "MEM"])
@@ -339,7 +286,7 @@ class TestWorkerCore(TestCase):
             pass
 
         class MyProcessor(Processor):
-            def process(self, msg: Input) -> Output:
+            def process(self, msg: Input, id: str) -> Output:
                 return Output()
 
         msgs = [{}, {}, {}]
@@ -428,7 +375,7 @@ class TestWorkerCore(TestCase):
                 splitter.start()
                 assert len(splitter.destinations) == 3
 
-    def test_logging(self):
+    def test_logging(self, monkeypatch):
         class Input(BaseModel):
             key: int
 
@@ -436,7 +383,7 @@ class TestWorkerCore(TestCase):
             key: int
 
         class MyProcessor(Processor):
-            def process(self, msg):
+            def process(self, msg, id):
                 self.logger.info("logging")
                 return msg
 
@@ -448,12 +395,15 @@ class TestWorkerCore(TestCase):
             description="",
             in_kind=TapKind.MEM,
             out_kind=TapKind.MEM,
+            debug=True,
+            monitoring=True,
         )
         processor = MyProcessor(
             settings, input_class=Input, output_class=Output, logger=logger
         )
         processor.parse_args(args="--out-topic test".split())
         processor.source.data = msgs
+        monkeypatch.setattr(processor, "monitor", mock.MagicMock())
         processor.start()
         assert len(processor.destination.results) == 3
         logger.info.assert_any_call("logging")
@@ -467,7 +417,7 @@ class TestWorkerCore(TestCase):
             key: int
 
         class MyProcessor(Processor):
-            def process(self, msg: Input) -> Output:
+            def process(self, msg: Input, id: str) -> Output:
                 return Output(key=1)
 
         logger = mock.MagicMock()
